<?php

namespace Service\ChartView;

class Card extends ChartViewAbstract implements ChartViewInterface {

    const TYPE_ID_CARD = "57b368d4adda8e5b20295f6c";

    public $widget;
    public $widgetData;

    function __construct($widget = null) {
        $this->widget = $widget;
        $this->widgetData = [];
    }

    protected function fontShouldBeWhite($color) { 
        $c = substr($color,1); // strip #
        $rgb = intval($c, 16); // convert rrggbb to decimal
        $r = ($rgb >> 16) & 0xff; // extract red
        $g = ($rgb >> 8) & 0xff; // extract green
        $b = ($rgb >> 0) & 0xff; // extract blue

        $luma = 0.2126 * $r + 0.7152 * $g + 0.0722 * $b;
        return $luma < 155;
    }

    protected function getCardTitle($textColor){
        $widget = $this->widget;
        $customCss = !empty($widget["CSS_TITLE"]) ? $widget["CSS_TITLE"] : "";
        $cardTitle = [
            "name" => "cardTitle_".$widget["id"],
            "component" => "TekCardTitle",
            "title" => !empty($widget["cardTitle"]) ? $widget["cardTitle"] : $widget["label"],
            "cssClass" => "zmartCardTitle_$textColor",
            "events" => [
                "onMounted" => "{{ChartViewController.cardTitleOnMounted}}"
            ]
        ];
        if(!empty($widget["showPeriod"]) && $widget["showPeriod"] == "Y" && !empty($widget["period"]) && !empty($widget["period"]["start"]) && !empty($widget["period"]["end"]) ){
            $cardTitle["subtitle"] = "De ".$widget["period"]["start"]." a ".$widget["period"]["end"];
        }
        if(!empty($customCss)){
            $cardTitle["cssStyle"] = $customCss;
        }

        return $cardTitle;
    }

    protected function getCardValue($textColor){
        $widget = $this->widget;
        $widgetData = $this->widgetData;
        $cardValue = !empty($widgetData[0][$widget["cardValue"]]) ? $widgetData[0][$widget["cardValue"]] : 0;
        $customCss = !empty($widget["CSS_VALUE"]) ? $widget["CSS_VALUE"] : "";
        return [
            "name" => "cardValue_".$widget["id"],
            "component" => "ZdText",
            "cssClass" => "zd-text-center zmartCard",
            "cssStyle" => "color: $textColor;height: 90%;$customCss",
            "text" => "<div class='zd-display-flex zd-justify-center' style='height:100%;'><div class='zd-align-self-center' style='font-size:56px;'>".strval($cardValue)."</div></div>",
            "cardData" => $widgetData[0],
            "widget" => $widget,
        ];
    }

    public function convertToNext():array {
        $this->fetchWidgetData();
        $widget = $this->widget;
        $widgetData = $this->widgetData;

        $cardColor = !empty($widget["cardColors"]) ? $widget["cardColors"] : "";
        if(is_array($cardColor)){
            $cardColor = $cardColor[0];
        }
        $textColor = $this->fontShouldBeWhite($cardColor) ? "white" : "black";
        $indicatorNext = [
            "name" => "apexChart_" . $widget['id'],
            "id" => $widget['id'],
            "widget" => $widget,
            "viewTypeId" => self::TYPE_ID_CARD,
            "component" => self::CARD_COMPONENT,
            "height" =>"100%",
            "style" =>"height: 100%; background-color: ".$cardColor.";",
            "children" => [
                $this->getCardTitle($textColor),
                $this->getCardValue($textColor),
            ],
        ];

        $this->widget = $indicatorNext;
        return $indicatorNext;
    }
}
