<?php

namespace Service;


use Util\Utilities;
use Util\Environment;
use \Teknisa\Model\Geral\Entities;
use Doctrine\ORM\EntityManager;
use Util\InstanceProvider;

class ZmartAccessProfile {

    const NRORG = "NRORG";

    /** @var Environment $environment */
    protected  $environment;

    /** @var EntityManager $entityManager */
    protected $entityManager;

    public function __construct(Environment $environment, EntityManager $entityManager) {
        $this->environment = $environment;
        $this->entityManager = $entityManager;
    }

    public function getNrOrgFilter() {
        return Utilities::getOrganizationIdForFindAcl();
    }

    public function find($conditions, $page, $pageSize)
    {
        $filters = Utilities::createQueryFiltered($conditions);
        $nrorgPrincipal = Utilities::getNrorgPrincipal();
        $organizationId = $this->getNrOrgFilter();
        $limit = $page * $pageSize;
        $offset = ($page - 1) * $pageSize;
        return $this->findOperators($organizationId, $nrorgPrincipal, $filters, $limit, $offset);
    }

    public function findOperators($organizationId, $nrorgPrincipal, $filters, $limit, $offset)
    {
        $stingNrorgPrincipal = '';
        if($nrorgPrincipal){
            $stingNrorgPrincipal = " OR NRORG = $nrorgPrincipal";
        }
        $query = <<<SQL
            SELECT CDOPERULTATU, NRORGULTATU, CDOPERINCLUSAO, NRORGINCLUSAO, DTULTATU, DTINCLUSAO, IDATIVO, NRORG,
                   NRUSERGROUP, NMPERFILACESSO, NRPERFACESSOPAI, NRPERFILACESSO, IDPERFILACESSOADM
              FROM PERFILACESSO
             WHERE (NRORG = $organizationId $stingNrorgPrincipal)
             $filters
SQL;

        $queryWithPagination = Utilities::getPaginatedQuery($query, $limit, $offset);
        $entityManager = InstanceProvider::getConnectionCustom()->updateVpdConnection($organizationId,true);
        $entityManager = $entityManager ? $entityManager : InstanceProvider::getEntityManager();
        return $entityManager->getConnection()->fetchAll($queryWithPagination);
    }
}
